# Fardel Ecommerce Extension

This repository is an ecommerce extension for FardelCMS.

## Installation

1 - Install the extension with pypi: `$ pip install fardel_ecommerce`

2 - Then add `fardel_ecommerce` to your `config.ACTIVE_APPS`.

3 - Run migration and upgrade command.
